@@ -1,4 +1,5 @@
-from typing import List, Optional, TypedDict
+from typing import List, Optional, TypedDict, Dict
+
 
 class ProjectConfig(TypedDict):
     project_type: str
@@ -7,14 +8,16 @@ class ProjectConfig(TypedDict):
     tag: str
     pred_label: Optional[str]
     feature_exclude: Optional[List[str]]
+    drop_duplicate_uid: Optional[bool]
 
 
 class DataConfig(TypedDict):
     tags: List[str]
     feature_exclude: List[str]
-    feature_encodings: List[str]
+    feature_encodings: Dict[str, str]
     drop_duplicate_uid: bool
 
+
 class SyntheticDataConfig(TypedDict):
     model_name: str
     tags: List[str]
@@ -23,6 +26,7 @@ class SyntheticDataConfig(TypedDict):
     feature_actual_used: List[str]
     drop_duplicate_uid: bool
 
+
 class SyntheticModelHyperParams(TypedDict):
     # GPT2 hyper params
     batch_size: Optional[int]
@@ -34,6 +38,6 @@ class SyntheticModelHyperParams(TypedDict):
     tabular_config: Optional[str]
     train_size: Optional[float]
 
-    #CTGAN hyper params
+    # CTGAN hyper params
     epochs: Optional[int]
-    test_ratio: Optional[float]
\ No newline at end of file
+    test_ratio: Optional[float]
